@@ -30,32 +30,24 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID(PKG_VER "$Id: groupdel.c,v 1.14 2000/10/09 19:02:20 kloczek Exp $")
-
+RCSID (PKG_VER "$Id: groupdel.c,v 1.20 2005/04/06 04:26:06 kloczek Exp $")
 #include <sys/types.h>
 #include <stdio.h>
 #include <grp.h>
 #include <ctype.h>
 #include <fcntl.h>
 #include <pwd.h>
-
 #ifdef USE_PAM
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
 #include <pwd.h>
-#endif /* USE_PAM */
-
+#endif				/* USE_PAM */
+#include "nscd.h"
 #include "prototypes.h"
 #include "defines.h"
-
-static char	*group_name;
-static char	*Prog;
-static int	errors;
-
-#ifdef	NDBM
-extern	int	gr_dbm_mode;
-extern	int	sg_dbm_mode;
-#endif
+static char *group_name;
+static char *Prog;
+static int errors;
 
 #include "groupio.h"
 
@@ -76,21 +68,20 @@ static int is_shadow_grp;
 #define E_GRP_UPDATE	10	/* can't update group file */
 
 /* local function prototypes */
-static void usage(void);
-static void grp_update(void);
-static void close_files(void);
-static void open_files(void);
-static void group_busy(gid_t);
+static void usage (void);
+static void grp_update (void);
+static void close_files (void);
+static void open_files (void);
+static void group_busy (gid_t);
 
 /*
  * usage - display usage message and exit
  */
 
-static void
-usage(void)
+static void usage (void)
 {
-	fprintf(stderr, _("usage: groupdel group\n"));
-	exit(E_USAGE);
+	fprintf (stderr, _("Usage: groupdel group\n"));
+	exit (E_USAGE);
 }
 
 /*
@@ -99,63 +90,24 @@ usage(void)
  *	grp_update() writes the new records to the group files.
  */
 
-static void
-grp_update(void)
+static void grp_update (void)
 {
-#ifdef	NDBM
-	struct	group	*ogrp;
-#endif
-
-	if (!gr_remove(group_name)) {
-		fprintf(stderr, _("%s: error removing group entry\n"), Prog);
+	if (!gr_remove (group_name)) {
+		fprintf (stderr, _("%s: error removing group entry\n"), Prog);
 		errors++;
 	}
-#ifdef	NDBM
-
-	/*
-	 * Update the DBM group file
-	 */
-
-	if (gr_dbm_present()) {
-		if ((ogrp = getgrnam (group_name)) &&
-				! gr_dbm_remove (ogrp)) {
-			fprintf(stderr, _("%s: error removing group dbm entry\n"),
-				Prog);
-			errors++;
-		}
-	}
-	endgrent ();
-#endif	/* NDBM */
 
 #ifdef	SHADOWGRP
-
 	/*
 	 * Delete the shadow group entries as well.
 	 */
-
-	if (is_shadow_grp && ! sgr_remove (group_name)) {
-		fprintf(stderr, _("%s: error removing shadow group entry\n"),
-			Prog);
+	if (is_shadow_grp && !sgr_remove (group_name)) {
+		fprintf (stderr,
+			 _("%s: error removing shadow group entry\n"), Prog);
 		errors++;
 	}
-#ifdef	NDBM
-
-	/*
-	 * Update the DBM shadow group file
-	 */
-
-	if (is_shadow_grp && sg_dbm_present()) {
-		if (! sg_dbm_remove (group_name)) {
-			fprintf(stderr,
-				_("%s: error removing shadow group dbm entry\n"),
-				Prog);
-			errors++;
-		}
-	}
-	endsgent ();
-#endif	/* NDBM */
-#endif	/* SHADOWGRP */
-	SYSLOG((LOG_INFO, "remove group `%s'\n", group_name));
+#endif				/* SHADOWGRP */
+	SYSLOG ((LOG_INFO, "remove group `%s'\n", group_name));
 	return;
 }
 
@@ -166,23 +118,22 @@ grp_update(void)
  *	new group.  This causes any modified entries to be written out.
  */
 
-static void
-close_files(void)
+static void close_files (void)
 {
-	if (!gr_close()) {
-		fprintf(stderr, _("%s: cannot rewrite group file\n"), Prog);
+	if (!gr_close ()) {
+		fprintf (stderr, _("%s: cannot rewrite group file\n"), Prog);
 		errors++;
 	}
-	gr_unlock();
+	gr_unlock ();
 #ifdef	SHADOWGRP
-	if (is_shadow_grp && !sgr_close()) {
-		fprintf(stderr, _("%s: cannot rewrite shadow group file\n"),
-			Prog);
+	if (is_shadow_grp && !sgr_close ()) {
+		fprintf (stderr,
+			 _("%s: cannot rewrite shadow group file\n"), Prog);
 		errors++;
 	}
 	if (is_shadow_grp)
-		sgr_unlock();
-#endif	/* SHADOWGRP */
+		sgr_unlock ();
+#endif				/* SHADOWGRP */
 }
 
 /*
@@ -191,29 +142,28 @@ close_files(void)
  *	open_files() opens the two group files.
  */
 
-static void
-open_files(void)
+static void open_files (void)
 {
-	if (!gr_lock()) {
-		fprintf(stderr, _("%s: unable to lock group file\n"), Prog);
-		exit(E_GRP_UPDATE);
+	if (!gr_lock ()) {
+		fprintf (stderr, _("%s: unable to lock group file\n"), Prog);
+		exit (E_GRP_UPDATE);
 	}
-	if (!gr_open(O_RDWR)) {
-		fprintf(stderr, _("%s: unable to open group file\n"), Prog);
-		exit(E_GRP_UPDATE);
+	if (!gr_open (O_RDWR)) {
+		fprintf (stderr, _("%s: unable to open group file\n"), Prog);
+		exit (E_GRP_UPDATE);
 	}
 #ifdef	SHADOWGRP
-	if (is_shadow_grp && !sgr_lock()) {
-		fprintf(stderr, _("%s: unable to lock shadow group file\n"),
-			Prog);
-		exit(E_GRP_UPDATE);
+	if (is_shadow_grp && !sgr_lock ()) {
+		fprintf (stderr,
+			 _("%s: unable to lock shadow group file\n"), Prog);
+		exit (E_GRP_UPDATE);
 	}
-	if (is_shadow_grp && !sgr_open(O_RDWR)) {
-		fprintf(stderr, _("%s: unable to open shadow group file\n"),
-			Prog);
-		exit(E_GRP_UPDATE);
+	if (is_shadow_grp && !sgr_open (O_RDWR)) {
+		fprintf (stderr,
+			 _("%s: unable to open shadow group file\n"), Prog);
+		exit (E_GRP_UPDATE);
 	}
-#endif	/* SHADOWGRP */
+#endif				/* SHADOWGRP */
 }
 
 /*
@@ -224,10 +174,9 @@ open_files(void)
  *	the group.
  */
 
-static void
-group_busy(gid_t gid)
+static void group_busy (gid_t gid)
 {
-	struct	passwd	*pwd;
+	struct passwd *pwd;
 
 	/*
 	 * Nice slow linear search.
@@ -235,8 +184,7 @@ group_busy(gid_t gid)
 
 	setpwent ();
 
-	while ((pwd = getpwent ()) && pwd->pw_gid != gid)
-		;
+	while ((pwd = getpwent ()) && pwd->pw_gid != gid);
 
 	endpwent ();
 
@@ -251,16 +199,16 @@ group_busy(gid_t gid)
 	 * Can't remove the group.
 	 */
 
-	fprintf(stderr, _("%s: cannot remove user's primary group.\n"), Prog);
-	exit(E_GROUP_BUSY);
+	fprintf (stderr, _("%s: cannot remove user's primary group.\n"), Prog);
+	exit (E_GROUP_BUSY);
 }
 
 #ifdef USE_PAM
 static struct pam_conv conv = {
-    misc_conv,
-    NULL
+	misc_conv,
+	NULL
 };
-#endif /* USE_PAM */
+#endif				/* USE_PAM */
 
 /*
  * main - groupdel command
@@ -272,10 +220,10 @@ static struct pam_conv conv = {
  *	The named group will be deleted.
  */
 
-int
-main(int argc, char **argv)
+int main (int argc, char **argv)
 {
 	struct group *grp;
+
 #ifdef USE_PAM
 	pam_handle_t *pamh = NULL;
 	struct passwd *pampw;
@@ -286,35 +234,40 @@ main(int argc, char **argv)
 	 * Get my name so that I can use it to report errors.
 	 */
 
-	Prog = Basename(argv[0]);
+	Prog = Basename (argv[0]);
 
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	setlocale (LC_ALL, "");
+	bindtextdomain (PACKAGE, LOCALEDIR);
+	textdomain (PACKAGE);
+
+	if (argc != 2)
+		usage ();
+
+	group_name = argv[1];
 
 #ifdef USE_PAM
 	retval = PAM_SUCCESS;
 
-	pampw = getpwuid(getuid());
+	pampw = getpwuid (getuid ());
 	if (pampw == NULL) {
 		retval = PAM_USER_UNKNOWN;
 	}
 
 	if (retval == PAM_SUCCESS) {
-		retval = pam_start("shadow", pampw->pw_name, &conv, &pamh);
+		retval = pam_start ("groupdel", pampw->pw_name, &conv, &pamh);
 	}
 
 	if (retval == PAM_SUCCESS) {
-		retval = pam_authenticate(pamh, 0);
+		retval = pam_authenticate (pamh, 0);
 		if (retval != PAM_SUCCESS) {
-			pam_end(pamh, retval);
+			pam_end (pamh, retval);
 		}
 	}
 
 	if (retval == PAM_SUCCESS) {
-		retval = pam_acct_mgmt(pamh, 0);
+		retval = pam_acct_mgmt (pamh, 0);
 		if (retval != PAM_SUCCESS) {
-			pam_end(pamh, retval);
+			pam_end (pamh, retval);
 		}
 	}
 
@@ -322,60 +275,40 @@ main(int argc, char **argv)
 		fprintf (stderr, _("%s: PAM authentication failed\n"), Prog);
 		exit (1);
 	}
-#endif /* USE_PAM */
+#endif				/* USE_PAM */
 
-	if (argc != 2)
-		usage ();
-
-	group_name = argv[1];
-
-	OPENLOG(Prog);
+	OPENLOG ("groupdel");
 
 #ifdef SHADOWGRP
-	is_shadow_grp = sgr_file_present();
+	is_shadow_grp = sgr_file_present ();
 #endif
 
-	/*
-	 * The open routines for the DBM files don't use read-write
-	 * as the mode, so we have to clue them in.
-	 */
-
-#ifdef	NDBM
-	gr_dbm_mode = O_RDWR;
-#ifdef	SHADOWGRP
-	sg_dbm_mode = O_RDWR;
-#endif	/* SHADOWGRP */
-#endif	/* NDBM */
-
 	/*
 	 * Start with a quick check to see if the group exists.
 	 */
-
-	if (! (grp = getgrnam(group_name))) {
-		fprintf(stderr, _("%s: group %s does not exist\n"),
-			Prog, group_name);
-		exit(E_NOTFOUND);
+	if (!(grp = getgrnam (group_name))) {
+		fprintf (stderr, _("%s: group %s does not exist\n"),
+			 Prog, group_name);
+		exit (E_NOTFOUND);
 	}
-#ifdef	USE_NIS
 
+#ifdef	USE_NIS
 	/*
 	 * Make sure this isn't a NIS group
 	 */
-
 	if (__isgrNIS ()) {
-		char	*nis_domain;
-		char	*nis_master;
+		char *nis_domain;
+		char *nis_master;
 
-		fprintf(stderr, _("%s: group %s is a NIS group\n"),
-			Prog, group_name);
+		fprintf (stderr, _("%s: group %s is a NIS group\n"),
+			 Prog, group_name);
 
-		if (! yp_get_default_domain (&nis_domain) &&
-				! yp_master (nis_domain, "group.byname",
-				&nis_master)) {
+		if (!yp_get_default_domain (&nis_domain) &&
+		    !yp_master (nis_domain, "group.byname", &nis_master)) {
 			fprintf (stderr, _("%s: %s is the NIS master\n"),
-				Prog, nis_master);
+				 Prog, nis_master);
 		}
-		exit(E_NOTFOUND);
+		exit (E_NOTFOUND);
 	}
 #endif
 
@@ -383,25 +316,24 @@ main(int argc, char **argv)
 	 * Now check to insure that this isn't the primary group of
 	 * anyone.
 	 */
-
 	group_busy (grp->gr_gid);
 
 	/*
 	 * Do the hard stuff - open the files, delete the group entries,
 	 * then close and update the files.
 	 */
-
 	open_files ();
 
 	grp_update ();
+	nscd_flush_cache ("group");
 
 	close_files ();
 
 #ifdef USE_PAM
 	if (retval == PAM_SUCCESS) {
-		retval = pam_chauthtok(pamh, 0);
+		retval = pam_chauthtok (pamh, 0);
 		if (retval != PAM_SUCCESS) {
-			pam_end(pamh, retval);
+			pam_end (pamh, retval);
 		}
 	}
 
@@ -411,8 +343,8 @@ main(int argc, char **argv)
 	}
 
 	if (retval == PAM_SUCCESS)
-		pam_end(pamh, PAM_SUCCESS);
-#endif /* USE_PAM */
-	exit(errors == 0 ? E_SUCCESS : E_GRP_UPDATE);
-	/*NOTREACHED*/
+		pam_end (pamh, PAM_SUCCESS);
+#endif				/* USE_PAM */
+	exit (errors == 0 ? E_SUCCESS : E_GRP_UPDATE);
+	/* NOT REACHED */
 }
